pub struct Pint { /* private fields */ }Expand description
Pin interrupt and pattern match (PINT)
Implementations
Sourceimpl Pint
impl Pint
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn ienr(self) -> Reg<Ienr, RW>
pub const fn ienr(self) -> Reg<Ienr, RW>
Pin interrupt level or rising edge interrupt enable register
Sourcepub const fn sienr(self) -> Reg<Sienr, W>
pub const fn sienr(self) -> Reg<Sienr, W>
Pin interrupt level or rising edge interrupt set register
Sourcepub const fn cienr(self) -> Reg<Cienr, W>
pub const fn cienr(self) -> Reg<Cienr, W>
Pin interrupt level (rising edge interrupt) clear register
Sourcepub const fn ienf(self) -> Reg<Ienf, RW>
pub const fn ienf(self) -> Reg<Ienf, RW>
Pin interrupt active level or falling edge interrupt enable register
Sourcepub const fn sienf(self) -> Reg<Sienf, W>
pub const fn sienf(self) -> Reg<Sienf, W>
Pin interrupt active level or falling edge interrupt set register